@@ -359,12 +359,12 @@ def yearly_returns(returns, benchmark=None,
             benchmark, returns.index).resample('A').apply(
                 _stats.compsum).resample('A').last()
 
-    returns = _utils._prepare_returns(returns).resample('A') 
-    if compounded: 
-        returns = returns.apply(_stats.compsum) 
-    else: 
-        returns = returns.apply(_df.cumsum) 
-    returns = returns.resample('A').last() 
+    returns = _utils._prepare_returns(returns).resample('A')
+    if compounded:
+        returns = returns.apply(_stats.compsum)
+    else:
+        returns = returns.apply(_df.cumsum)
+    returns = returns.resample('A').last()
 
     fig = _core.plot_returns_bars(returns, benchmark,
                                   fontname=fontname,
@@ -502,11 +502,11 @@ def rolling_volatility(returns, benchmark=None,
                        subtitle=True, savefig=None, show=True):
 
     returns = _utils._prepare_returns(returns)
-    returns = returns.rolling(period).std() * _np.sqrt(252)
+    returns = returns.rolling(period).std() * _np.sqrt(period)
 
     if benchmark is not None:
         benchmark = _utils._prepare_benchmark(benchmark, returns.index)
-        benchmark = benchmark.rolling(period).std() * _np.sqrt(252)
+        benchmark = benchmark.rolling(period).std() * _np.sqrt(period)
 
     fig = _core.plot_rolling_stats(returns, benchmark,
                                    hline=returns.mean(),
